clear all
discard
set more off

/*************************************************************************************************************
ramey_cr_arra.do

This is a modification of Chodorow-Reich's (AEJ:Economic Policy, forthcoming)
 do-file that creates the tables and figures for the paper. 

Modified by Valerie Ramey to create Table 4 of her JEP article
Ramey deleted most parts since they were not needed for her analysis.
Added parts are indicated by "Ramey added"

If a command, such as "estadd" gives an error message, type "search estadd" and follow
the instructions to download these free addons for Stata.

*************************************************************************************************************/

local start 2008m12
local startshort = string(tm(`start'),"%tmNNYY")
local end 2010m12

local load
if !(tm(`start')==tm(2008m12) & tm(`end')==tm(2010m12)) local outputps _`start'_`end'

cap log close
local datestring = string(date("$S_DATE","DMY"),"%tdCCYYNNDD")
log using ramey_cr_results.log, replace

/*************************************************************************************************************
Load data
*************************************************************************************************************/

use table1-dataset`outputps', clear

/*************************************************************************************************************
Appendix table 2 (additional control variables)
*************************************************************************************************************/
xi i.region
forvalues d=2/4 {
	local varlabels `"`varlabels' _Iregion_`d' `"Census region `d'"' "'
}
local F "F`=tm(`end')-tm(`start')'." 
local e total
local m ces
local norm pc
local instrument_list
foreach ivar in fmap dot dm {
	local instrument_list `"`instrument_list' `F'instrument_`ivar'_`norm'`startshort'"'
}
local instrument_label ALL
local hpi_control S12log_sa_fhfa L12S48log_sa_fhfa
local region_control _Iregion*
local manufacturing_control manshare

/*Renormalize variables so that controls are interpretable*/
qui replace C`m'_sa_`norm' = C`m'_sa_`norm'*10^(-2)
qui replace D`m'_sa_`norm' = D`m'_sa_`norm'*10^(-2)
foreach var of varlist outlays_`e'_`norm'`startshort' instrument_*_`norm'`startshort' DExpenditure_`norm' DTax_`norm' CExpenditure_`norm' CTax_`norm' {
	qui replace `var' = `var'*10^(-2)
}
lab var ces_sa_pc `"Dec-08 employment/population 16+"'
cap gen S12ces_sa_pc`startshort' = S12.ces_sa_pc`startshort'
lab var S12ces_sa_pc`startshort' `"Employment change, Dec-07 to Dec-08"'
cap gen L12DGSPR_gspr = L12.DGSPR_sa_gspr
lab var L12DGSPR_gspr `"GSP change, 2007Q4-2008Q4"'
cap gen S12log_sa_fhfa = S12.log_sa_fhfa
lab var S12log_sa_fhfa `"Log change in HPI, Dec-07 to Dec-08"'
cap gen L12S48log_sa_fhfa = L12S48.log_sa_fhfa
lab var L12S48log_sa_fhfa `"Log change in HPI, Dec-03 to Dec-07"'
lab var RealAnnualPI_3yrMADifference `"Change in 3 year m.a. of PI per cap., 2005 to 2006"'
lab var manshare `"Manufacturing share of employment, Dec-08"'

local controls
local nregs


foreach newcontrols in `"ces_sa_pc S12ces_sa_pc`startshort' L12DGSPR_gspr"' `"`hpi_control'"' `"RealAnnualPI_3yrMADifference"' `"`manufacturing_control'"' `"`region_control'"' {
	foreach newcontrol in `newcontrols' {
		if !regexm(`"`newcontrol'"',`"^_I"') {
			qui sum `newcontrol' if sample,
			gen `newcontrol'_n = `newcontrol'/r(sd) /*Normalize controls to have unit variance*/
			local controls `controls' `newcontrol'_n
			lab var `newcontrol'_n `"`:variable label `newcontrol''"'
		}
		else local controls `controls' `newcontrol'
	}
}


* Ramey added - back out state population by dividing Chodorow-Reich's non-per capita by per capita
gen xpop1208 = (1/100)*F6.outlays_total/F6.outlays_total_pc1208
by id: egen pop1208 = mean(xpop1208)

* end Ramey added

/*************************************************************************************************************
Ramey added:  Table 4 in JEP, extensions based on Chodorow-Reich Table 1 (main results)
Parts that are Ramey added:
  - extra regressions with weights
  - extra regressions with total state and local
*************************************************************************************************************/

local ces_controls `"ces_sa_pc_n S12ces_sa_pc`startshort'_n L12DGSPR_gspr_n"'
local GSPR_controls "ces_sa_pc_n S12ces_sa_pc`startshort'_n L12DGSPR_gspr_n"
local F "F`=tm(`end')-tm(`start')'." 
local e total
local nregs

*Chodorow-Reich Table 1, Column 4 regression.  Reproduced in Ramey, Table 4, Row 1
ivreg2 F24.Cces_sa_pc `ces_controls' (`F'outlays_total_pc`startshort'= F24.instrument_fmap_pc1208 ///
		   F24.instrument_dot_pc1208 F24.instrument_dm_pc1208) if sample, robust `estimator'

weakivtest

*Ramey modification of Chodorow-Reich regression to weight by population		   
ivreg2 F24.Cces_sa_pc `ces_controls' (`F'outlays_total_pc`startshort'= F24.instrument_fmap_pc1208 ///
		   F24.instrument_dot_pc1208 F24.instrument_dm_pc1208) [w=pop1208] if sample, robust `estimator'

weakivtest

*Ramey modification of Chodorow-Reich regression to (1) use all outlays, including state and local; (2) weight by population
ivreg2 F24.Cces_sa_pc `ces_controls' (F24.CExpenditure_pc= F24.instrument_fmap_pc1208 ///
		   F24.instrument_dot_pc1208 F24.instrument_dm_pc1208) [w=pop1208] if sample, robust `estimator'
		
weakivtest

log close
